@@ -1,4 +1,4 @@
-#   Copyright 2016 Red Hat, Inc. All Rights Reserved.
+#   Copyright 2017 Red Hat, Inc. All Rights Reserved.
 #
 #   Licensed under the Apache License, Version 2.0 (the "License"); you may
 #   not use this file except in compliance with the License. You may obtain
@@ -11,16 +11,17 @@
 #   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #   License for the specific language governing permissions and limitations
 #   under the License.
+"""
+ARA: Ansible Run Analysis
+"""
 
 import pbr.version
-from ara.webapp import create_app
 
 # Setup version
-version_info = pbr.version.VersionInfo('ara')
+VERSION = pbr.version.VersionInfo('ara')
 try:
-    __version__ = version_info.version_string()
-except AttributeError:
+    __version__ = VERSION.version_string()
+    __release__ = VERSION.release_string()
+except (ValueError, AttributeError):
     __version__ = None
-
-
-app = create_app()
+    __release__ = None
