@@ -1,10 +1,8 @@
-from .playbook import playbook
+from .about import about
 from .debug import debug
-from .host import host
-from .task import task
-from .result import result
-from .play import play
-from .home import home
 from .file import file
+from .host import host
+from .reports import reports
+from .result import result
 
 # flake8: noqa
